CREATE TABLE  "ANSWERS" 
   (  "QUESTION_NO" NUMBER NOT NULL ENABLE, 
   "CHOICE_LETTER" VARCHAR2(30) NOT NULL ENABLE, 
   "ANSWER" VARCHAR2(255), 
   "CATEGORY" VARCHAR2(30), 
    CONSTRAINT "ANSWERS_PK" PRIMARY KEY ("QUESTION_NO", "CHOICE_LETTER") ENABLE
   )
   STORAGE (INITIAL     5120  
               NEXT        5120 
               MINEXTENTS     1  
            MAXEXTENTS     5 )
/
CREATE TABLE  "DEPT" 
   (  "DEPTNO" NUMBER(2,0), 
   "DNAME" VARCHAR2(14), 
   "LOC" VARCHAR2(13), 
    PRIMARY KEY ("DEPTNO") ENABLE
   )
   STORAGE (INITIAL     5120  
               NEXT        5120 
               MINEXTENTS     1  
            MAXEXTENTS     5 )
/
CREATE TABLE  "EMP" 
   (  "EMPNO" NUMBER(4,0) NOT NULL ENABLE, 
   "ENAME" VARCHAR2(10), 
   "JOB" VARCHAR2(9), 
   "MGR" NUMBER(4,0), 
   "HIREDATE" DATE, 
   "SAL" NUMBER(7,2), 
   "COMM" NUMBER(7,2), 
   "DEPTNO" NUMBER(2,0), 
   "TEMP" CHAR(1) DEFAULT 'N' NOT NULL ENABLE, 
    PRIMARY KEY ("EMPNO") ENABLE, 
    FOREIGN KEY ("MGR")
     REFERENCES  "EMP" ("EMPNO") ENABLE, 
    FOREIGN KEY ("DEPTNO")
     REFERENCES  "DEPT" ("DEPTNO") ENABLE
   )
   STORAGE (INITIAL     5120  
               NEXT        5120 
               MINEXTENTS     1  
            MAXEXTENTS     5 )
/
CREATE TABLE  "PERSON" 
   (  "PERSON_NO" NUMBER NOT NULL ENABLE, 
   "PERSON_NAME" VARCHAR2(30), 
   "PASSWORD" VARCHAR2(20), 
   "EMAIL" VARCHAR2(50), 
   "ACTIVE" CHAR(1) DEFAULT 'Y' NOT NULL ENABLE, 
    CONSTRAINT "PERSON_PK" PRIMARY KEY ("PERSON_NO") ENABLE
   )
   STORAGE (INITIAL     5120  
               NEXT        5120 
               MINEXTENTS     1  
            MAXEXTENTS     5 )
/
CREATE TABLE  "TESTS" 
   (  "TEST_NO" NUMBER NOT NULL ENABLE, 
   "NAME" VARCHAR2(50), 
    CONSTRAINT "TESTS_PK" PRIMARY KEY ("TEST_NO") ENABLE
   )
   STORAGE (INITIAL     5120  
               NEXT        5120 
               MINEXTENTS     1  
            MAXEXTENTS     5 )
/
CREATE TABLE  "PERSON_TESTS" 
   (  "PERSON_NO" NUMBER NOT NULL ENABLE, 
   "TEST_NO" NUMBER NOT NULL ENABLE, 
    CONSTRAINT "PERSON_TEST_PK" PRIMARY KEY ("PERSON_NO", "TEST_NO") ENABLE, 
    CONSTRAINT "PER_TEST_PER_FK" FOREIGN KEY ("PERSON_NO")
     REFERENCES  "PERSON" ("PERSON_NO") ENABLE, 
    CONSTRAINT "PER_TEST_TEST_FK" FOREIGN KEY ("TEST_NO")
     REFERENCES  "TESTS" ("TEST_NO") ENABLE
   )
   STORAGE (INITIAL     5120  
               NEXT        5120 
               MINEXTENTS     1  
            MAXEXTENTS     5 )
/
CREATE TABLE  "QUESTIONS" 
   (  "QUESTION_NO" NUMBER NOT NULL ENABLE, 
   "TEST_NO" NUMBER NOT NULL ENABLE, 
   "QUESTION" VARCHAR2(500), 
    CONSTRAINT "QUESTIONS_PK" PRIMARY KEY ("TEST_NO", "QUESTION_NO") ENABLE, 
    CONSTRAINT "QUESTIONS_TEST_FK" FOREIGN KEY ("TEST_NO")
     REFERENCES  "TESTS" ("TEST_NO") ENABLE
   )
   STORAGE (INITIAL     5120  
               NEXT        5120 
               MINEXTENTS     1  
            MAXEXTENTS     5 )
/
CREATE TABLE  "RATINGS" 
   (  "TEST" NUMBER NOT NULL ENABLE, 
   "RATING" VARCHAR2(30) NOT NULL ENABLE, 
   "SHORT_DESCRIPTION" VARCHAR2(255), 
   "FULL_DESCRIPTION" VARCHAR2(4000), 
    CONSTRAINT "RATINGS_PK" PRIMARY KEY ("TEST", "RATING") ENABLE, 
    CONSTRAINT "RATINGS_TEST_FK" FOREIGN KEY ("TEST")
     REFERENCES  "TESTS" ("TEST_NO") ENABLE
   )
   STORAGE (INITIAL     5120  
               NEXT        5120 
               MINEXTENTS     1  
            MAXEXTENTS     5 )
/
CREATE TABLE  "RATINGS_CRITERIA" 
   (  "TEST" NUMBER NOT NULL ENABLE, 
   "RATING" VARCHAR2(30) NOT NULL ENABLE, 
   "CATEGORY" VARCHAR2(30) NOT NULL ENABLE, 
   "LOW_RANGE_COUNT" NUMBER, 
   "HIGH_RANGE_COUNT" NUMBER, 
    CONSTRAINT "RATINGS_CRITERIA_PK" PRIMARY KEY ("TEST", "RATING", "CATEGORY") ENABLE
   )
   STORAGE (INITIAL     5120  
               NEXT        5120 
               MINEXTENTS     1  
            MAXEXTENTS     5 )
/
CREATE TABLE  "RESULTS" 
   (  "PERSON_NO" NUMBER NOT NULL ENABLE, 
   "QUESTION_NO" NUMBER NOT NULL ENABLE, 
   "CHOICE" VARCHAR2(2), 
    CONSTRAINT "RESULTS_PK" PRIMARY KEY ("PERSON_NO", "QUESTION_NO") ENABLE
   )
   STORAGE (INITIAL     5120  
               NEXT        5120 
               MINEXTENTS     1  
            MAXEXTENTS     5 )
/
create table "LIFO_RESULTS" (
    "PERSON_NO"   NUMBER,
    "QUESTION_NO" NUMBER,
    "CHOICE"      VARCHAR2(2),
    "RANK"        NUMBER,
    constraint  "LIFO_RESULTS_PK" primary key ("PERSON_NO", "QUESTION_NO", "CHOICE")
)
   STORAGE (INITIAL     5120  
               NEXT        5120 
               MINEXTENTS     1  
            MAXEXTENTS     5 )
/
CREATE SEQUENCE PERSON_SEQ
START WITH 100
INCREMENT BY 1
MINVALUE 0
NOCACHE 
NOCYCLE 
NOORDER 
/
CREATE OR REPLACE TRIGGER "BI_PERSON"
BEFORE
insert on "PERSON"
for each row
begin
begin
for c1 in ( 
    select "PERSON_SEQ".nextval next_val 
    from dual 
  ) loop 
    :new."PERSON_NO" :=  c1.next_val; 
end loop;
end;
end;
/
